@@ -29,7 +29,7 @@ def Balrog(tool_pred, genome):
                         startCodon = genome[start - 1:start + 2]
                         stopCodon = genome[stop - 3:stop]
                     po = str(start) + ',' + str(stop)
-                    orf = [strand, startCodon, stopCodon]
+                    orf = [strand, startCodon, stopCodon, 'CDS']
                     Balrog_ORFs.update({po: orf})
 
     Balrog_ORFs = sortORFs(Balrog_ORFs)
