@@ -31,7 +31,7 @@ def FGENESB(tool_pred, genome):
                         startCodon = genome[start - 1:start + 2]
                         stopCodon = genome[stop - 3:stop]
                     po = str(start) + ',' + str(stop)
-                    orf = [strand, startCodon, stopCodon]
+                    orf = [strand, startCodon, stopCodon, 'CDS']
                     FGENESB_ORFs.update({po: orf})
 
     FGENESB_ORFs = sortORFs(FGENESB_ORFs)
