@@ -28,7 +28,7 @@ def GeneMark_S_2(tool_pred, genome):
                     startCodon = genome[start - 1:start + 2]
                     stopCodon = genome[stop - 3:stop]
                 po = str(start) + ',' + str(stop)
-                orf = [strand, startCodon, stopCodon]
+                orf = [strand, startCodon, stopCodon, 'CDS']
                 geneMark_S_2_ORFs.update({po: orf})
 
     geneMark_S_2_ORFs = sortORFs(geneMark_S_2_ORFs)
