@@ -29,7 +29,7 @@ def MetaGeneAnnotator(tool_pred, genome):
                         startCodon = genome[start - 1:start + 2]
                         stopCodon = genome[stop - 3:stop]
                     po = str(start) + ',' + str(stop)
-                    orf = [strand, startCodon, stopCodon]
+                    orf = [strand, startCodon, stopCodon, 'CDS']
                     metaGeneAnnotator_ORFs.update({po: orf})
 
     metaGeneAnnotator_ORFs = sortORFs(metaGeneAnnotator_ORFs)
