@@ -8,7 +8,8 @@ except ImportError:
     from ORForise.utils import sortORFs
 
 
-def Prodigal(tool_pred, genome):
+def Prodigal(**kwargs):
+    tool_pred, genome,types = list(kwargs.values())
     prodigalORFs = collections.OrderedDict()
     genome_size = len(genome)
     genome_rev = revCompIterative(genome)
@@ -28,7 +29,7 @@ def Prodigal(tool_pred, genome):
                     startCodon = genome[start - 1:start + 2]
                     stopCodon = genome[stop - 3:stop]
                 po = str(start) + ',' + str(stop)
-                orf = [strand, startCodon, stopCodon]
+                orf = [strand, startCodon, stopCodon, 'CDS']
                 prodigalORFs.update({po: orf})
 
     prodigalORFs = sortORFs(prodigalORFs)
